#
# spec file for package xdg-user-dirs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdg-user-dirs
Version:        0.18
Release:        2.9
Summary:        Utilities to handle user data directories
License:        GPL-2.0-only
Group:          System/GUI/Other
URL:            https://freedesktop.org/wiki/Software/xdg-user-dirs
Source0:        https://user-dirs.freedesktop.org/releases/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch1:         0001-Add-a-systemd-service-to-run-xdg-user-dirs-update.patch
BuildRequires:  make
BuildRequires:  suse-xsl-stylesheets
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
%systemd_ordering

%description
xdg-user-dirs is a tool to help manage "well known" user directories
like the desktop folder and the music folder. It also
handles localization (i.e. translation) of the filenames.

%lang_package

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install
install -Dm0644 xdg-user-dirs.service %{buildroot}%{_userunitdir}/xdg-user-dirs.service
# Change sr@Latn to sr@latin
mv %{buildroot}%{_datadir}/locale/sr@Latn %{buildroot}%{_datadir}/locale/sr@latin
%find_lang %{name} %{?no_lang_C}
# Create xinit script
mkdir -p %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d
echo "#!/bin/sh" >> %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/xdg-user-dirs.sh
echo "%{_bindir}/xdg-user-dirs-update" >> %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/xdg-user-dirs.sh
chmod a+x %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/xdg-user-dirs.sh
%suse_update_desktop_file %{name}

%pre
%systemd_user_pre xdg-user-dirs.service

%post
%systemd_user_post xdg-user-dirs.service

%preun
%systemd_user_preun xdg-user-dirs.service

%files
%license COPYING
%doc AUTHORS README ChangeLog
%{_mandir}/man1/*.1%{?ext_man}
%{_mandir}/man5/*.5%{?ext_man}
%config(noreplace) %{_sysconfdir}/xdg/user-dirs.conf
%config(noreplace) %{_sysconfdir}/xdg/user-dirs.defaults
%dir %{_sysconfdir}/X11/xinit
%dir %{_sysconfdir}/X11/xinit/xinitrc.d
%{_sysconfdir}/X11/xinit/xinitrc.d/xdg-user-dirs.sh
%{_bindir}/xdg-user-dir
%{_bindir}/xdg-user-dirs-update
%{_sysconfdir}/xdg/autostart/xdg-user-dirs.desktop
%{_userunitdir}/xdg-user-dirs.service

%files lang -f %{name}.lang

%changelog
* Mon Feb  6 2023 Fabian Vogt <fvogt@suse.com>
- Add patch to provide a systemd user service
  (gh#systemd/systemd#18791, boo#1201728):
  * 0001-Add-a-systemd-service-to-run-xdg-user-dirs-update.patch
* Tue Oct 25 2022 Matthias Eliasson <elimat@opensuse.org>
- update to 0.18:
  + Fixed minor leak
  + Updated translations
  + Documentation fixes
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri Jan 31 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend -lang: supplements are in use.
* Wed Oct 24 2018 sean@suspend.net
- update to 0.17:
  + Respect $HOME in favor of getpwuid()
  + Updated translations
  + Documentation spelling fixes
* Fri Oct 20 2017 astieger@suse.com
- update to 0.16:
  + Add autostart file for user-dirs-update
  + Update translations
* Thu Aug  1 2013 zaitor@opensuse.org
- Update to version 0.15:
  + Added manpages.
  + Updated translations.
- Add suse-xsl-stylesheets BuildRequires in order to build the
  added manpages.
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sat Jul 21 2012 dimstar@opensuse.org
- Split out -lang package (bnc#645077).
* Sun Jul 24 2011 andrea.turrini@gmail.com
- Fixed typo in description of xdg-user-dirs.spec
* Wed May  4 2011 vuntz@opensuse.org
- Update to version 0.14:
  + Fix permissions of ~/.config if created (should be 0700)
  + Updated translations
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Sep 14 2010 vuntz@opensuse.org
- Update to version 0.13:
  + Fix a memleak
  + Updated translations
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 0.12:
  + Updated translations
- Changes from version 0.11:
  + Switch DOWNLOAD default to "Downloads" instead of "Download" to
    to match the other names
  + Fix bashisms in xdg-user-dirs
  + Updated translations
- Use spec-cleaner to clean the spec file.
- Drop sr-latin-rename.diff and instead rename the .mo file after
  the "make install" call.
- Do not package empty TODO file.
* Sun Feb  1 2009 dmueller@suse.de
- sr@Latn -> sr@latin
* Wed Feb 27 2008 stbinner@suse.de
- update to 0.10:
  * New translations
  * Update cut and paste code to handle oom and c++
* Mon Oct 22 2007 stbinner@suse.de
- update to 0.9: new translations, relocatable, fix possible crash
* Tue Jul 17 2007 stbinner@suse.de
- initial package of version 0.8
